/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 *   @OMA_DS_Platform_Event_Handler.h
 *   @version									0.1
 *   @brief										This file is the header file of interface for event callback function(platform monitor)
 */

#ifndef OMA_DS_PLATFORM_EVENT_HANDLER_H_
#define OMA_DS_PLATFORM_EVENT_HANDLER_H_

#include <glib.h>
#include <stdio.h>
#include <stdbool.h>

/**
 * @par Description: API to parse callback function for SAN
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, msg body
 * @param[in]		unsigned int type, size of msg
 * @param[in]		int type, version
 * @param[out]
 *
 * @return				1 on success
 * 						0 on fail
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int san_callback_parse(int item_id, void *user_data);

/**
 * @par Description: This API is callback function for scheduler
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		scheduler Id
 * @param[in]		user data
 * @param[out]
 *
 * @return
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
void send_periodic_sync_msg(int scheduler_id, void *data);

/**
 * @par Description: This API is for receive ip push msg from event
 *
 * Parse ip push msg and request sync
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		data(ip push message)
 *
 * @return				1 on success
 * 						0 on fail
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int send_ip_push_sync_msg(char *data);

#endif				/* OMA_DS_PLATFORM_EVENT_HANDLER_H_ */
