/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 *   @SA_DevInf.h
 *   @version									0.1
 *   @brief										This file is the header file of interface of DevInf structure
 */

#ifndef SA_DEVINF_H_
#define SA_DEVINF_H_

#include "service-adapter/sa_define.h"

/**
 * @par Description: API to create devinf_s structure
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		session_s structure
 * @param[out]		devinf_s  structure
 *
 * @return			ERROR_INTERNAL_OK on success
 *						ERROR_INTERNAL_ERROR, ERROR_INTERNAL_NOT_DEFINED, ERROR_INTERNAL_NO_MEMORY on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
sa_error_type_e create_devinf(session_s * session, devinf_s ** devinf);

/**
 * @par Description: API to free devinf_s structure
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		devinf_s  structure
 *
 * @return
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
void free_devinf(devinf_s * devinf);

/**
 * @par Description: API to set sync cap in devinf_datastore_s structure
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		devinf_datastore_s structure
 * @param[in]		devinf_sync_cap_e sync type
 * @param[in]		whether support or not
 *
 * @return
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
void set_devinf_datastore_sync_cap(devinf_datastore_s * devinf_datastore, devinf_sync_cap_e cap, int supported);

/**
 * @par Description: API to get sync cap from devinf_datastore_s structure
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		devinf_datastore_s structure
 * @param[in]		devinf_sync_cap_e sync type
 *
 * @return				True on success
 *							False on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int get_devinf_datastore_sync_cap(const devinf_datastore_s * devinf_datastore, devinf_sync_cap_e cap);

/*
DevInfSyncCap convert_devinf_synccap(unsigned int id);
*/
#endif				/* SA_DEVINF_H_ */
