/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 *   @SA_Session_Internal.h
 *   @version									0.1
 *   @brief										This file is the header file of session structure is defined
 *													Session, PendingStatus
 */

#ifndef SA_SESSION_INTERNAL_H_
#define SA_SESSION_INTERNAL_H_

#include "service-adapter/sa_define.h"

struct session {
	protocol_version_e protocol_version;
	protocol_type_e protocol_type;

	char *session_id;
	unsigned int msg_id;
	unsigned int last_recieved_msg_id;
	unsigned int cmd_id;
	int is_sending_final;
	int is_receiving_final;

	GList *status;		/*status to return to server */
	GList *temp_status;	/*temp status for sync add, replace, delete command(it doesnot have data element value) */
	GList *suspend_status;	/* for suspend */
	location_s *target;
	location_s *source;
	location_s *org_target;

	unsigned int source_max_msg_size;
	unsigned int source_max_obj_size;

	unsigned int target_max_msg_size;
	unsigned int target_max_obj_size;

	cred_s *cred;		/*account info */
	chal_s *chal;		/*chal from server */

	devinf_s *devinf;	/*client devinf */
	devinf_s *remote_devinf;	/*server devinf */

	pkg_status_e pkg_status;	/*for status */

	command_s *large_obj_cmd;	/*for incomming large Command */

	GList *map_command;	/*containing map command that has sent to server(this is used to for delete map item from mapping table) */

	GList *alert_command;	/*containing alert command that have to send to server */

	GList *results_command;	/*containing results command */

	command_status_s *large_obj;	/*for outgoing large command */

	int has_opend;
	unsigned int naci_session_id;

	int account_id;
	char *jsession_id;
};

struct command_status {
	unsigned int cmd_id;
	unsigned int msg_id;
};
#endif				/* SA_SESSION_INTERNAL_H_ */
